import { formatHashTag, formatPriceDiv } from "@/common/fotmat"
import { View } from "@tarojs/components"
import { memo, useCallback, useMemo } from "react"
import EstimatedAmount from "../estimatedAmount"
import styles  from './index.module.scss'

type OrderParam = {
    estimate_amount: number, //预估金额
    list: any[], 
    sale_mode: number,
    sale_mode_name: string,
    unit: string,
    total_colors: number,
    total_fabrics: number,
    total_number: number,
    status: number, //订单状态
    total_sale_price: number, //销售金额
    total_should_collect_money: number, //应收金额
    total_weight_error_discount: number, //空差优惠

}

export default memo(({value}:{value?:OrderParam}) => {
    //对应数量
    const formatCount = useCallback((item) => {
        return value?.sale_mode == 0? item.roll : Number(item.length / 100)
    }, [value])
    //对应单价
    const standardPrice = useCallback(price => {
        return formatPriceDiv(price).toLocaleString() + '/' + (value?.sale_mode == 1?'m':'kg')
    }, [value])

    //数量格式
    const numText = useMemo(() => {
        if(value)
            return `${value?.total_fabrics}种面料，${value?.total_colors}种颜色，共${value?.total_number}${value?.unit}`
    }, [value])

    const priceConDom = useMemo(() => {
        return (
            <>
                {(value&&value.status < 3)&&<EstimatedAmount number={formatPriceDiv(value?.estimate_amount)} title="预估金额" />}     
                {(value&&value.status >= 3)&&<EstimatedAmount number={formatPriceDiv(value?.total_sale_price)} titleStatus={false}  numberStatus={0} title="合计金额" />}      
                {(value&&value.status >= 3)&&<EstimatedAmount number={formatPriceDiv(value?.total_weight_error_discount)} titleStatus={false} numberStatus={0} title="空差优惠" />}      
                {(value&&value.status >= 3)&&<EstimatedAmount number={formatPriceDiv(value?.total_should_collect_money)} title="应付金额" />} 
            </>
        )
    }, [value])
    
    return (
        <>
            <View className={styles.orders_list_title}>{numText}</View>
            <View className={styles.orders_list_con}>
                {
                    value?.list?.map(item => {
                        return <View key={item.product_code} className={styles.order_list}>
                            <View className={styles.order_list_title}>
                                <View className={styles.tag}>{value.sale_mode_name}</View>
                                <View className={styles.title}>{formatHashTag(item.code, item.name)}</View>
                                <View className={styles.num}>共{item?.product_colors.length}种</View>
                            </View>
                            <View className={styles.order_list_scroll}>
                                {item?.product_colors?.map(colorItem => {
                                    return <View key={colorItem.id} className={styles.order_list_item}>
                                        <View className={styles.order_list_item_img}></View>
                                        <View className={styles.order_list_item_con}>
                                            <View className={styles.order_list_item_des}>
                                                <View className={styles.order_list_item_title}>{colorItem.code + ' ' + colorItem.name}</View>
                                                <View className={styles.order_list_item_price}>¥{standardPrice(colorItem.sale_price)}</View>
                                            </View>
                                            <View className={styles.order_list_item_count}>
                                                <View className={styles.count_num}>×{formatCount(colorItem)}<text>{value.unit}</text></View>
                                                <View className={styles.count_price}><text>¥</text>{formatPriceDiv(colorItem.estimate_amount).toLocaleString()}</View>
                                            </View>
                                        </View>
                                    </View>
                                })}
                            </View>
                        </View>
                    })
                }
                <View className={styles.order_estimated_amount}>
                    {priceConDom}     
                </View>
            </View>
        </>
    )
})